class WikiInfo:
    def __init__(self, wiki_data_id, wikipedia_url, wikipedia_title, wiki_data_item):
        self.wiki_data_id = wiki_data_id
        self.wikipedia_url = wikipedia_url
        self.wikipedia_title = wikipedia_title
        self.wiki_data_item = wiki_data_item
